@@ -113,7 +113,7 @@ class MockComm(object):
         return d
 
     def Reduce(self, sendbuf, recvbuf, op=None, root=0):
-        if sendbuf is IN_PLACE:
+        if isinstance(sendbuf, int) and (sendbuf == IN_PLACE):
             sendbuf = recvbuf.copy()
 
         if not isinstance(sendbuf, np.ndarray):
@@ -130,6 +130,10 @@ class MockComm(object):
         self.Reduce(sendbuf, recvbuf, op)
         self.Bcast(recvbuf)
 
+    def allgather(self, sendobj):
+        obj = self.gather(sendobj)
+        return self.bcast(obj)
+
     # Instance methods not implemented
     def Abort(self, *args, **kwargs):
         raise NotImplementedError("The method 'Abort' is not implemented in mockmpi")
@@ -492,11 +496,6 @@ class MockComm(object):
             "The method 'Ssend_init' is not implemented in mockmpi"
         )
 
-    def allgather(self, *args, **kwargs):
-        raise NotImplementedError(
-            "The method 'allgather' is not implemented in mockmpi"
-        )
-
     def barrier(self, *args, **kwargs):
         raise NotImplementedError("The method 'barrier' is not implemented in mockmpi")
 
